@@ -44,7 +44,7 @@ from datamodel_code_generator.types import DataType, DataTypeManager, StrictType
 
 escape_characters = str.maketrans(
     {
-        "\\": r"\\",
+        '\\': r'\\',
         "'": r"\'",
         '\b': r'\b',
         '\f': r'\f',
@@ -171,7 +171,7 @@ def sort_data_models(
                 model.reference_classes - {model.path} - set(sorted_data_models)
             )
             base_models = [
-                getattr(s.reference, "path", None) for s in model.base_classes
+                getattr(s.reference, 'path', None) for s in model.base_classes
             ]
             update_action_parent = set(require_update_action_models).intersection(
                 base_models
@@ -187,7 +187,7 @@ def sort_data_models(
                 continue
             # unresolved
             unresolved_classes = ', '.join(
-                f"[class: {item.path} references: {item.reference_classes}]"
+                f'[class: {item.path} references: {item.reference_classes}]'
                 for item in unresolved_references
             )
             raise Exception(f'A Parser can not resolve classes: {unresolved_classes}.')
@@ -661,7 +661,7 @@ class Parser(ABC):
                     )
 
                 if init:
-                    from_ = "." + from_
+                    from_ = '.' + from_
                 imports.append(Import(from_=from_, import_=import_, alias=alias))
 
     @classmethod
@@ -777,7 +777,6 @@ class Parser(ABC):
                     # set copied data_type
                     copied_data_type = root_type_field.data_type.copy()
                     if isinstance(data_type.parent, self.data_model_field_type):
-
                         # for field
                         # override empty field by root-type field
                         model_field.extras = dict(
@@ -916,7 +915,7 @@ class Parser(ABC):
 
         models.sort(key=lambda x: x.class_name)
 
-        imported = set(i for v in imports.values() for i in v)
+        imported = {i for v in imports.values() for i in v}
         model_class_name_baseclasses: Dict[DataModel, Tuple[str, Set[str]]] = {}
         for model in models:
             class_name = model.class_name
@@ -943,7 +942,6 @@ class Parser(ABC):
         format_: Optional[bool] = True,
         settings_path: Optional[Path] = None,
     ) -> Union[str, Dict[Tuple[str, ...], Result]]:
-
         self.parse_raw()
 
         if with_import:
@@ -979,6 +977,7 @@ class Parser(ABC):
         unused_models: List[DataModel] = []
         model_to_models: Dict[DataModel, List[DataModel]] = {}
 
+        previous_module = ()  # type: Tuple[str, ...]
         for module, models in (
             (k, [*v]) for k, v in grouped_models
         ):  # type: Tuple[str, ...], List[DataModel]
@@ -986,12 +985,21 @@ class Parser(ABC):
                 model_to_models[model] = models
             self.__delete_duplicate_models(models)
             self.__replace_duplicate_name_in_module(models)
+            if len(previous_module) - len(module) > 1:
+                for parts in range(len(previous_module) - 1, len(module), -1):
+                    module_models.append(
+                        (
+                            previous_module[:parts],
+                            [],
+                        )
+                    )
             module_models.append(
                 (
                     module,
                     models,
                 )
             )
+            previous_module = module
 
         class Processed(NamedTuple):
             module: Tuple[str, ...]
@@ -1054,7 +1062,9 @@ class Parser(ABC):
             if code_formatter:
                 body = code_formatter.format_code(body)
 
-            results[module] = Result(body=body, source=models[0].file_path)
+            results[module] = Result(
+                body=body, source=models[0].file_path if models else None
+            )
 
         # retain existing behaviour
         if [*results] == [('__init__.py',)]:
