@@ -47,7 +47,13 @@ from datamodel_code_generator.parser.base import (
     title_to_class_name,
 )
 from datamodel_code_generator.reference import ModelType, Reference, is_url
-from datamodel_code_generator.types import DataType, DataTypeManager, StrictTypes, Types
+from datamodel_code_generator.types import (
+    DataType,
+    DataTypeManager,
+    EmptyDataType,
+    StrictTypes,
+    Types,
+)
 
 
 def get_model_by_path(
@@ -268,7 +274,7 @@ class JsonSchemaObject(BaseModel):
 
     @cached_property
     def type_has_null(self) -> bool:
-        return isinstance(self.type, list) and "null" in self.type
+        return isinstance(self.type, list) and 'null' in self.type
 
 
 @lru_cache()
@@ -290,8 +296,8 @@ def _get_type(type_: str, format__: Optional[str] = None) -> Types:
         return data_formats
 
     warn(
-        "format of {!r} not understood for {!r} - using default"
-        "".format(format__, type_)
+        'format of {!r} not understood for {!r} - using default'
+        ''.format(format__, type_)
     )
     return json_schema_data_formats[type_]['default']
 
@@ -616,7 +622,6 @@ class JsonSchemaParser(Parser):
         base_classes: List[Reference],
         required: List[str],
     ) -> DataType:
-
         if obj.properties:
             fields.extend(
                 self.parse_object_fields(obj, path, get_module_name(name, None))
@@ -1091,6 +1096,8 @@ class JsonSchemaParser(Parser):
 
             if len(data_types) > 1:
                 data_type = self.data_type(data_types=data_types)
+            elif not data_types:
+                return EmptyDataType()
             else:  # pragma: no cover
                 data_type = data_types[0]
         elif obj.patternProperties:
@@ -1412,10 +1419,10 @@ class JsonSchemaParser(Parser):
             self.parse_array(name, obj, path)
         elif obj.allOf:
             self.parse_all_of(name, obj, path)
-        elif obj.oneOf:
-            self.parse_root_type(name, obj, path)
-        elif obj.anyOf:
-            self.parse_root_type(name, obj, path)
+        elif obj.oneOf or obj.anyOf:
+            data_type = self.parse_root_type(name, obj, path)
+            if isinstance(data_type, EmptyDataType) and obj.properties:
+                self.parse_object(name, obj, path)
         elif obj.properties:
             self.parse_object(name, obj, path)
         elif obj.patternProperties:
@@ -1530,7 +1537,6 @@ class JsonSchemaParser(Parser):
                 path, obj_name, unique=False, class_name=True
             ).name
             with self.root_id_context(raw):
-
                 # parse $id before parsing $ref
                 root_obj = JsonSchemaObject.parse_obj(raw)
                 self.parse_id(root_obj, path_parts)
