@@ -43,19 +43,24 @@ from datamodel_code_generator.parser.jsonschema import (
     get_special_path,
 )
 from datamodel_code_generator.reference import snake_to_upper_camel
-from datamodel_code_generator.types import DataType, DataTypeManager, StrictTypes
+from datamodel_code_generator.types import (
+    DataType,
+    DataTypeManager,
+    EmptyDataType,
+    StrictTypes,
+)
 
 RE_APPLICATION_JSON_PATTERN: Pattern[str] = re.compile(r'^application/.*json$')
 
 OPERATION_NAMES: List[str] = [
-    "get",
-    "put",
-    "post",
-    "delete",
-    "patch",
-    "head",
-    "options",
-    "trace",
+    'get',
+    'put',
+    'post',
+    'delete',
+    'patch',
+    'head',
+    'options',
+    'trace',
 ]
 
 
@@ -297,8 +302,10 @@ class OpenAPIParser(JsonSchemaParser):
             # TODO: The List model is not created by this method. Some scenarios may necessitate it.
         elif obj.allOf:  # pragma: no cover
             data_type = self.parse_all_of(name, obj, path)
-        elif obj.oneOf:  # pragma: no cover
+        elif obj.oneOf or obj.anyOf:  # pragma: no cover
             data_type = self.parse_root_type(name, obj, path)
+            if isinstance(data_type, EmptyDataType) and obj.properties:
+                self.parse_object(name, obj, path)
         elif obj.is_object:
             data_type = self.parse_object(name, obj, path)
         elif obj.enum:  # pragma: no cover
@@ -337,13 +344,13 @@ class OpenAPIParser(JsonSchemaParser):
                 ref_model = self.get_ref_model(detail.ref)
                 content = {
                     k: MediaObject.parse_obj(v)
-                    for k, v in ref_model.get("content", {}).items()
+                    for k, v in ref_model.get('content', {}).items()
                 }
             else:
                 content = detail.content
 
             if self.allow_responses_without_content and not content:
-                data_types[status_code]["application/json"] = DataType(type='None')
+                data_types[status_code]['application/json'] = DataType(type='None')
 
             for content_type, obj in content.items():
                 object_schema = obj.schema_
@@ -537,13 +544,12 @@ class OpenAPIParser(JsonSchemaParser):
                 if OpenAPIScope.Paths in self.open_api_scopes:
                     paths: Dict[str, Dict[str, Any]] = specification.get('paths', {})
                     parameters: List[Dict[str, Any]] = [
-                        self._get_ref_body(p['$ref']) if '$ref' in p else p  # type: ignore
+                        self._get_ref_body(p['$ref']) if '$ref' in p else p
                         for p in paths.get('parameters', [])
                         if isinstance(p, dict)
                     ]
                     paths_path = [*path_parts, '#/paths']
                     for path_name, methods in paths.items():
-
                         paths_parameters = parameters[:]
                         if 'parameters' in methods:
                             paths_parameters.extend(methods['parameters'])
